######################################
rm(list=ls())
setwd("/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/Sim-Cages/")
library(data.table)
library(dplyr)

##########################

#### FUNCTIONS ###########

#distinct.wt: determines, 
distinct.wt<-function(x.df,target.column1,target.column2){
  x.df$p1.distinct<-ifelse(x.df[,target.column1]<1,1,0)
  x.df$p2.distinct<-ifelse(x.df[,target.column2]<1,1,0)
  x.df$p1.distinct[is.na(x.df[,target.column1])]<-1
  x.df$p2.distinct[is.na(x.df[,target.column2])]<-1
  x.df$p.distinct<-as.integer(x.df$p1.distinct & x.df$p2.distinct)
  return(x.df)
}

#distinct.wt: 
distinct.wt.single<-function(x.df,target.column){
  x.df$p.distinct<-ifelse(x.df[,target.column]<1,1,0)
  x.df$p.distinct[is.na(x.df[,target.column])]<-1
  return(x.df)
}

#read.data: read (subset of) data 
read.data<-function(x,filter=FALSE){
  temp<-readRDS(x)
  if(filter){
    temp<-subset(temp,model==filter)
  }
  return(temp)
}

#calculate.best: calculates the number of simulations in which the true model can explain the data best
calculate.best<-function(x,my.choice,my.competitors){
  x.s<-subset(x,model%in%c(my.choice,my.competitors))
  x.s %>% group_by(p1,p2,sim) %>% summarize(best=model[which.max(L)]) -> x.best
  x.best %>% group_by(p1,p2) %>% summarize(best.count=length(best[which(best==my.choice)])) -> x.best.count
  return(x.best.count)
}

#calculate.CI: calculates, if estimated selection parameter(s) is/are distinguishable from 1 (= 0 fitness cost)
calculate.CI<-function(x,target.column1,target.column2=FALSE){
  if(target.column2!=FALSE){
    x<-distinct.wt(x,target.column1 = target.column1, target.column2 = target.column2)
    print(head(x))
    x %>% group_by(p1,p2) %>% summarize(mean.p1.distinct=sum(p1.distinct),mean.p2.distinct=sum(p2.distinct),mean.p.distinct=sum(p.distinct)) -> x.ci
  } else {
    x<-distinct.wt.single(x,target.column = target.column1)
    x %>% group_by(p1,p2) %>% summarize(mean.p.distinct=sum(p.distinct)) -> x.ci
  }
  return(x.ci)
}

#calculate.euclidean: calculates euclidean distance between x and y
calculate.euclidean<-function(x,y){
  eucl<-sqrt(sum(c(x-y)^2))
  return(eucl)
}

#calculate.euclidean.z: calculates euclidean distance between x and y, divided by y
calculate.euclidean.z<-function(x,y){
  eucl<-sqrt(sum(c(c(x-y)/x)^2))
  return(eucl)
}

#call.euclidean: calls euclidean distance functions, for 1 or 2 selection parameters
call.euclidean<-function(x,multiple=FALSE){
  if(multiple!=FALSE){
    x %>% group_by(p1,p2,sim) %>% mutate(euclidean=calculate.euclidean(c(p1,p2),c(est.p1,est.p2))) -> x.eucl
  } else {
    x %>% group_by(p1,p2,sim) %>% mutate(euclidean=calculate.euclidean(c(p1,p2),c(est.p1,est.p1))) -> x.eucl
  }
  x.eucl %>% group_by(p1,p2) %>% summarize(mean.euclidean=mean(euclidean)) -> x.eucl.m
  return(x.eucl.m)
}

#call.euclidean.modified: calls calculate.euclidean.z function, for 1 or 2 selection parameters
call.euclidean.modified<-function(x,multiple=FALSE){
  if(multiple!=FALSE){
    x %>% group_by(p1,p2,sim) %>% mutate(euclidean=calculate.euclidean.z(c(p1,p2),c(est.p1,est.p2))) -> x.eucl
  } else {
    x %>% group_by(p1,p2,sim) %>% mutate(euclidean=calculate.euclidean.z(c(p1,p2),c(est.p1,est.p1))) -> x.eucl
  }
  x.eucl %>% group_by(p1,p2) %>% summarize(mean.euclidean=mean(euclidean)) -> x.eucl.m
  return(x.eucl.m)
}

#calculate.sd: calculates the standard deviation between true and estimated parameter(s)
calculate.sd<-function(x,multiple=FALSE){
  if(multiple!=FALSE) {
  x %>% group_by(p1,p2) %>% summarize(sd.est.p1=sd(est.p1),sd.est.p2=sd(est.p2)) -> x.sd } else {
    x %>% group_by(p1,p2) %>% summarize(sd.est.p1=sd(est.p1)) -> x.sd
  }
  return(x.sd)
}


##########################

###### DATA   ############

  my.files<-list.files(pattern = glob2rx("*.rds"))
  head(my.files)
  fecundity<-my.files[grep("data-f.rds",my.files)]
  sexsel<-my.files[grep("data-s.rds",my.files)]
  via<-my.files[grep("data-v.rds",my.files)]
  
  via.data<-sapply(via,read.data,filter=FALSE,simplify = FALSE)
  via.data<-rbindlist(via.data)
  saveRDS(via.data,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-2params.rds")
  rm(via.data)

  fec.data<-sapply(fecundity,read.data,filter=FALSE,simplify = FALSE)
  fec.data<-rbindlist(fec.data)
  saveRDS(fec.data,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-2params.rds")
  rm(fec.data)

  sexsel.data<-sapply(sexsel,read.data,filter=FALSE,simplify = FALSE)
  sexsel.data<-rbindlist(sexsel.data)
  saveRDS(sexsel.data,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-2params.rds")
  rm(sexsel.data)


##########################
  
###### STATISTICS  #######

  #viability
  via.L<-calculate.best(via,my.choice = "v",my.competitors = c("s","f"))
  saveRDS(via.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-vs2Log.rds" )

  via.L<-calculate.best(via,my.choice = "v",my.competitors = c("s"))
  saveRDS(via.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-vsSexSelLog.rds" )
  
  via.L<-calculate.best(via,my.choice = "v",my.competitors = c("f"))
  saveRDS(via.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-vsFecLog.rds" )
  rm(via.L)


  via.s<-subset(via,as.character(model)==as.character(data))
  via.s<-as.data.frame(via.s)
  via.L<-calculate.CI(via.s,target.column1 = "ci.p1.upper", target.column2 = "ci.p2.upper")
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-CI-2params.rds")

  via.s<-subset(via,model=="v.simple")
  via.s<-as.data.frame(via.s)
  via.L<-calculate.CI(via.s,target.column1 = "ci.p1.upper")
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-CI-1param.rds")

  via.s<-subset(via,as.character(model)==as.character(data))
  via.L<-call.euclidean(via.s,multiple = TRUE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-euclidean.rds")
  via.L<-call.euclidean.modified(via.s,multiple = TRUE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-euclidean-scaled.rds")
  via.L<-calculate.sd(via.s,multiple = TRUE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-sd.rds")
  via.s<-subset(via,model=="v.simple")
  via.L<-call.euclidean(via.s,multiple = FALSE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-euclidean-1param.rds")
  via.L<-call.euclidean.modified(via.s,multiple = FALSE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-euclidean-1param-scaled.rds")
  via.L<-calculate.sd(via.s,multiple = FALSE)
  saveRDS(via.L,"/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Viability-sd-1param.rds")

  
  rm(via,via.L,via.s)

  #fecundity
  fec.L<-calculate.best(fec,my.choice = c("f"),my.competitors = c("s","v"))
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-vs2Log.rds")

  fec.L<-calculate.best(fec,my.choice = c("f"),my.competitors = c("s"))
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-vsSexSelLog.rds")

  fec.L<-calculate.best(fec,my.choice = c("f"),my.competitors = c("v"))
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-vsViaLog.rds")
  rm(fec.L)

  fec.s<-subset(fec,as.character(model)==as.character(data))
  fec.s<-as.data.frame(fec.s)
  fec.L<-calculate.CI(fec.s,target.column1 = "ci.p1.upper",target.column2 = "ci.p2.upper")
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-CI-2params.rds")

  fec.s<-subset(fec,model=="f.simple")
  fec.s<-as.data.frame(fec.s)
  fec.L<-calculate.CI(fec.s,target.column1 = "ci.p1.upper")
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-CI-1param.rds")
  rm(fec.L,fec.s)

  fec.s<-subset(fec,as.character(model)==as.character(data))
  fec.s<-as.data.frame(fec.s)
  fec.L<-call.euclidean(fec.s,multiple = TRUE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-euclidean.rds")
  fec.L<-call.euclidean.modified(fec.s,multiple = TRUE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-euclidean-scaled.rds")
  fec.L<-calculate.sd(fec.s,multiple = TRUE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-sd.rds")

  
  fec.s<-subset(fec,model=="f.simple")
  fec.L<-call.euclidean(fec.s,multiple = FALSE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-euclidean-1param.rds")
  fec.L<-call.euclidean.modified(fec.s,multiple = FALSE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-euclidean-1param-scaled.rds")

  fec.L<-calculate.sd(fec.s,multiple = FALSE)
  saveRDS(fec.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-Fecundity-sd-1param.rds")

  
  rm(fec,fec.L,fec.s)
  
#sexual selection
  sel.L<-calculate.best(sel,my.choice = c("s"),my.competitors = c("f","v"))
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-vs2Log.rds")
  
  sel.L<-calculate.best(sel,my.choice = c("s"),my.competitors = c("f"))
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-vsFecLog.rds")
  
  sel.L<-calculate.best(sel,my.choice = c("s"),my.competitors = c("v"))
  saveRDS(sel.L,file = "//Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-vsViaLog.rds")
  rm(sel.L)
  
  sel.s<-subset(sel,as.character(model)==as.character(data))
  sel.s<-as.data.frame(sel.s)
  sel.L<-calculate.CI(sel.s,target.column1 = "ci.p1.upper",target.column2 = "ci.p2.upper")
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-CI-2params.rds")
  rm(sel.L,sel.s)
  
  sel.s<-subset(sel,model=="s.simple")
  sel.s<-as.data.frame(sel.s)
  sel.L<-calculate.CI(sel.s,target.column1 = "ci.p1.upper")
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-CI-1param.rds")
  rm(sel.L,sel.s)

  sel.s<-subset(sel,as.character(model)==as.character(data))
  sel.s<-as.data.frame(sel.s)
  sel.L<-call.euclidean(sel.s,multiple = TRUE)
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-euclidean.rds")
  sel.L<-call.euclidean.modified(sel.s,multiple = TRUE)
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-euclidean-scaled.rds")
  sel.L<-calculate.sd(sel.s,multiple = TRUE)
  saveRDS(sel.L,file="/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-sd.rds")
  sel.s<-subset(sel,model=="s.simple")
  sel.L<-call.euclidean(sel.s,multiple = FALSE)
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-euclidean-1param.rds")
  sel.L<-call.euclidean.modified(sel.s,multiple = FALSE)
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-euclidean-1param-scaled.rds")
  sel.L<-calculate.sd(sel.s,multiple = FALSE)
  saveRDS(sel.L,file = "/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/20181106-SexualSelection-sd-1param.rds")
rm(sel.s,sel.L)


##########################

###### PLOTS  ############

rm(list=ls())
setwd("/Users/aml452/Documents/Messer/data/Simulations/Sim-Autosomal-Recessive-Genetics/")
#load function hetamap to generate heatmaps for the simulations 
source("functions/heatmap.R")

library(plyr)
library(dplyr)
library(ggpubr)

my.files<-list.files(pattern = ".rds")

#create.plots: function to generate several plots and calculate convex hulls
create.plots<-function(togrep,my.files){
  mf<-my.files[grep(togrep,my.files)]
  
  #95 % CI + single lines 
  thres<-0.95
  my.df<-readRDS(mf[grep("CI-2params.rds",mf)])
  my.df.p1<-subset(my.df,select = c("p1","p2","mean.p1.distinct"))
  my.df.p1$mean.p1.distinct<-my.df.p1$mean.p1.distinct/1000
  
  CI.p1<-subset(my.df.p1,mean.p1.distinct>=thres)
  CI.p1$dummyID<-rep("1",nrow(CI.p1))
  CI.p1$dummyID<-factor(CI.p1$dummyID,levels = c("1","2"))
  c.hull.p1<-chull(CI.p1[,c("p1","p2")])
  set.p1<-CI.p1[c.hull.p1,]
  set.p1<-arrange(set.p1,p1,p2)
  print(set.p1)
  
  my.df.p2<-subset(my.df,select = c("p1","p2","mean.p2.distinct"))
  my.df.p2$mean.p2.distinct<-my.df.p2$mean.p2.distinct/1000
  
  CI.p2<-subset(my.df.p2,mean.p2.distinct>=thres)
  CI.p2$dummyID<-rep("2",nrow(CI.p2))
  CI.p2$dummyID<-factor(CI.p2$dummyID,levels = c("1","2"))
  c.hull.p2<-chull(CI.p2[,c("p1","p2")])
  set.p2<-CI.p2[c.hull.p2,]
  set.p2<-arrange(set.p2,p1,p2)
  print(set.p2)
  
  my.df<-readRDS(mf[grep("CI-1param.rds",mf)])
  my.df<-subset(my.df,select = c("p1","p2","mean.p.distinct"))
  my.df$mean.p.distinct<-my.df$mean.p.distinct/1000

  CI.p<-subset(my.df,mean.p.distinct>=thres)
  c.hull.p<-chull(CI.p[,c("p1","p2")])
  set.p<-CI.p[c.hull.p,]
  set.p<-arrange(set.p,p1,p2)
  print(set.p)
  
  #manual correction and naming
  if(togrep=="SexualSelection"){
    ex<-c(1,2,11,12)
    set.p1<-set.p1[-ex,]
    ex<-c(1,8)
    set.p2<-set.p2[-ex,]
    ex<-c(1,2,6,7)
    set.p<-set.p[-ex,]
    x.label<-quote(alpha)
    y.label<-quote(beta)
    l.title<-"Sexual Selection only"
    vsA<-"Fec"
    titleA<-c("Sexual Selection vs. Fecundity")
    vsB<-"Via"
    titleB<-c("Sexual Selection vs. Viability")
  }
  
  if(togrep=="Fecundity"){
    ex<-c(1,8)
    set.p1<-set.p1[-ex,]
    ex<-c(1,11)
    set.p2<-set.p2[-ex,]
    ex<-c(1,2,5,6)
    set.p<-set.p[-ex,]
    x.label<-quote(omega)
    y.label<-quote(omega)
    l.title<-"Fecundity only"
    vsA<-"Via"
    titleA<-c("Fecundity vs. Viability")
    vsB<-"SexSel"
    titleB<-c("Fecundity vs. Sexual Selection")
  }

  if(togrep=="Viability"){
    ex<-c(1,2)
    set.p1<-set.p1[-ex,]
    ex<-c(1,2,7)
    set.p2<-set.p2[-ex,]
    ex<-c(1,2,8)
    set.p<-set.p[-ex,]
    m<-"m"
    x.label<-quote(nu)
    y.label<-quote(nu)
    l.title<-"Viability"
    vsA<-"SexSel"
    titleA<-c("Viability vs. Sexual Selection")
    vsB<-"Fec"
    titleB<-c("Viaibility vs. Fecundity")
  }
 
  #set colours
  my.log.colors<-c("blue","white","red","darkred")
  my.log.borders<-c(0,0.33,0.95,1)
  my.df<-readRDS(mf[grep("vs2Log.rds",mf)])
  print(head(my.df))
  
  #counts where true model explains data best (1 vs. 2)
  my.df$best.count<-my.df$best.count/1000
  gvs2<-make.heatmap(my.df,x.label = bquote(.(as.name(x.label)))  ,y.label =bquote(.(as.name(y.label))) ,title = l.title ,my.colors = my.log.colors,my.range = my.log.borders,bar.min = 0,bar.max = 1)
  print(gvs2)
  
  #1 vs. 1 comparisons
  my.df<-readRDS(mf[grep(paste("vs",vsA,"Log.rds",sep=""),mf)])
  my.df$best.count<-my.df$best.count/1000
  my.log.borders<-c(0,0.5,0.95,1)
  gvsA<-make.heatmap(my.df,x.label = bquote(.(as.name(x.label))) ,y.label = bquote(.(as.name(y.label))) ,title = titleA,my.colors = my.log.colors,my.range = my.log.borders,bar.max = 1,bar.min = 0)

  my.df<-readRDS(mf[grep(paste("vs",vsB,"Log.rds",sep=""),mf)])
  my.df$best.count<-my.df$best.count/1000
  gvsB<-make.heatmap(my.df,x.label = bquote(.(as.name(x.label))) ,y.label = bquote(.(as.name(y.label))) ,title = titleB,my.colors = my.log.colors,my.range = my.log.borders,bar.max = 1,bar.min = 0)


  g.CI2<-ggplot(data=my.df,aes(x=p1,y=p2))+scale_x_continuous(breaks = seq(0,max(my.df$p1),length.out = 5))+theme_minimal()+theme(text = element_text(size = 40),legend.text = element_text(size = 40))+coord_equal()+xlim(0,1)+ylim(0,1)
  g.CI2<-g.CI2+xlab(bquote(.(as.name(x.label))))+ylab(bquote(.(as.name(y.label))))
  g.CI2<-g.CI2+geom_line(data=set.p1,col="red",size=1)
  g.CI2<-g.CI2+geom_line(data=set.p2,col="blue",size=1)

  g.CI1<-ggplot(data=my.df,aes(x=p1,y=p2))+scale_x_continuous(breaks = seq(0,max(my.df$p1),length.out = 5))+theme_minimal()+theme(text = element_text(size = 40),legend.text = element_text(size = 40))+coord_equal()+xlim(0,1)+ylim(0,1)
  g.CI1<-g.CI1+xlab(bquote(.(as.name(x.label))))+ylab(bquote(.(as.name(y.label))))
  g.CI1<-g.CI1+geom_line(data=set.p,col="black",size=2)

  #euclidean distance, 2 parameters 
  eucl.2params<-readRDS(mf[grep("euclidean.rds",mf)])
  my.colors.euclidean.p2<-c("#276419","#e6f5d0","#c51b7d")
  my.borders.euclidean.p2<-c(0,0.1,0.42)
  g.2params<-make.heatmap(eucl.2params,x.label = bquote(.(as.name(x.label))),y.label = bquote(.(as.name(y.label))),title = paste("d(",l.title,")",sep=""),my.colors =my.colors.euclidean.p2,bar.min = 0,bar.max =0.42,my.range = my.borders.euclidean.p2)
  g.2params<-g.2params+geom_line(data=set.p1,col="black",linetype="twodash",size=1)+geom_line(data=set.p2,col="black",linetype="dotted",size=1)
  
  #euclidean distance, 1 parameter
  eucl.1param<-readRDS(mf[grep("euclidean-1param.rds",mf)])
  my.colors.euclidean.p1<-c("#276419","#e6f5d0","#c51b7d","#400e68")
  my.borders.euclidean.p1<-c(0,0.1,0.42,1)
  
  g.1param<-make.heatmap(eucl.1param,x.label = bquote(.(as.name(x.label))) ,y.label = bquote(.(as.name(y.label))),title = paste("d(",l.title,"), 1"),my.colors = my.colors.euclidean.p1,bar.min =0, bar.max =1,my.range =my.borders.euclidean.p1)
  g.1param<-g.1param+geom_line(data=set.p,col="black",linetype="twodash",size=1)
  
  return(list(gvs2,g.2params,g.CI2,gvsA,gvsB,g.1param,g.CI1))
}


#################################################

g.via<-create.plots("Viability",my.files)
g.sex<-create.plots("SexualSelection",my.files)
g.fec<-create.plots("Fecundity",my.files)
setwd("/Users/aml452/Documents/Messer/res/20181126-ML/")


#Viability 

#[[1]] vs. 2 
g.via[[1]]<-g.via[[1]]+xlab(expression(nu[m]))+ylab(expression(nu[f]))
png("Autosomal-Viability-ACCvs2.png",width = 1000,height = 1000)
print(g.via[[1]])
dev.off()

#[[2]] 2 params
g.via[[2]]<-g.via[[2]]+xlab(expression(nu[m]))+ylab(expression(nu[f]))
png("Euclidean-Viability-2params.png",width = 1000,height = 1000)
print(g.via[[2]])
dev.off()

#[[4]] vsA
g.via[[4]]<-g.via[[4]]+xlab(expression(nu[m]))+ylab(expression(nu[f]))
png("Autosomal-Viability-ACCvsSexualSelection.png",width = 1000,height = 1000)
print(g.via[[4]])
dev.off()

#[[5]] vsB
g.via[[5]]<-g.via[[5]]+xlab(expression(nu[m]))+ylab(expression(nu[f]))
png("Autosomal-Viability-ACCvsFecundity.png",width = 1000,height = 1000)
print(g.via[[5]])
dev.off()

#[[6]] 1 param
png("Euclidean-Viability-1param.png",width = 1000,height = 1000)
print(g.via[[6]])
dev.off()


#Sexual Selection

#[[1]] vs. 2 
png("Autosomal-SexualSelection-ACCvs2.png",width = 1000,height = 1000)
print(g.sex[[1]])
dev.off()

#[[2]] 2 params
png("Euclidean-SexualSelection-2params.png",width = 1000,height = 1000)
print(g.sex[[2]])
dev.off()

#[[4]] vsA
png("Autosomal-SexualSelection-ACCvsFecundity.png",width = 1000,height = 1000)
print(g.sex[[4]])
dev.off()

#[[5]] vsB
png("Autosomal-SexualSelection-ACCvsViability.png",width = 1000,height = 1000)
print(g.sex[[5]])
dev.off()

#[[6]] 1 param
png("Euclidean-SexualSelection-1param.png",width = 1000,height = 1000)
print(g.sex[[6]])
dev.off()


#Fecundity 

#[[1]] vs. 2 
g.fec[[1]]<-g.fec[[1]]+xlab(expression(f[m]))+ylab(expression(f[f]))
g.fec[[1]]
png("Autosomal-Fecundity-ACCvs2.png",width = 1000,height = 1000)
print(g.fec[[1]])
dev.off()

#[[2]] 2 params
g.fec[[2]]<-g.fec[[2]]+xlab(expression(f[m]))+ylab(expression(f[f]))
g.fec[[2]]
png("Euclidean-Fecundity-2params.png",width = 1000,height = 1000)
print(g.fec[[2]])
dev.off()

#[[4]] vsA
g.fec[[4]]<-g.fec[[4]]+xlab(expression(f[m]))+ylab(expression(f[f]))
g.fec[[4]]
png("Autosomal-Fecundity-ACCvsViability.png",width = 1000,height = 1000)
print(g.fec[[4]])
dev.off()

#[[5]] vsB
g.fec[[5]]<-g.fec[[5]]+xlab(expression(f[m]))+ylab(expression(f[f]))
png("Autosomal-Fecundity-ACCvsSexualSelection.png",width = 1000,height = 1000)
print(g.fec[[5]])
dev.off()

#[[6]] 1 param
g.fec[[6]]<-g.fec[[6]]+xlab(expression(f))+ylab(expression(f))
png("Euclidean-Fecundity-1param.png",width = 1000,height = 1000)
print(g.fec[[6]])
dev.off()

###################

#plots of autosomal data in the supplement

#Figure S2, A (from left to right): g.sex[[2]], g.via[[2]], g.fec[[2]]
#Figure S2, B (from left to right): g.sex[[6]], g.via[[6]], g.fec[[6]]

#Figure S3 (from left to right): g.sex[[1]], g.via[[1]], g.fec[[1]]

#Figure S4, first row (from left to right): g.sex[[5]], g.via[[4]], g.fec[[5]]
#Figure S4, second row (from left to right): g.sex[[4]], g.via[[5]], g.fec[[4]]

