
#x... vector of allele frequencies (M.ww,M.wd,M.dd,F.ww,F.wd,F.dd)
#w... 3x3 fecundity matrix (rows=males, cols=females)
#g... number of generations
#alpha ... vector for sexual selection of ww females (m.wd, m.dd)
#beta .... vector for sexual selection of wd females (m.wd, m.dd)
#gamma... vector for sexual selection of dd females (m.wd, m.dd)
#v.m ... vector for viability of males (v.m.wd, v.m.dd)
#v.f ... vector for viabilitY of females (v.f.wd, v.f.dd)
#n.e ... effective population size

evolve <- function(x,n.e,v.m,v.f,w,alpha,beta,gamma,g) {
  
  t <- x
  
  for(i in (1:g)) {
    #calculate sexual selection coefficients
    #x[1]=M.ww
    #x[2]=M.wd
    #x[3]=M.dd
    P.ww.ww <-x[1]/c(x[1]+alpha[1]*x[2]+alpha[2]*x[3])
    P.wd.ww <-c(alpha[1]*x[2])/c(x[1]+alpha[1]*x[2]+alpha[2]*x[3])
    P.dd.ww <-c(alpha[2]*x[3])/c(x[1]+alpha[1]*x[2]+alpha[2]*x[3])
    
    P.ww.wd<-x[1]/c(x[1]+beta[1]*x[2]+beta[2]*x[3])
    P.wd.wd<-c(beta[1]*x[2])/c(x[1]+beta[1]*x[2]+beta[2]*x[3])
    P.dd.wd<-c(beta[2]*x[3])/c(x[1]+beta[1]*x[2]+beta[2]*x[3])
    
    P.ww.dd<-x[1]/c(x[1]+gamma[1]*x[2]+gamma[2]*x[3])
    P.wd.dd<-c(gamma[1]*x[2])/c(x[1]+gamma[1]*x[2]+gamma[2]*x[3])
    P.dd.dd<-c(gamma[2]*x[3])/c(x[1]+gamma[1]*x[2]+gamma[2]*x[3])
    
    #calculate expected genotype frequencies
    #x[4]=F.ww
    #x[5]=F.wd
    #x[6]=F.dd
    
    #wildtype homozygotes
    m.ww <- x[4] * (P.ww.ww * w[1,1] + P.wd.ww * w[2,1]/2) + x[5]/2 * (P.ww.wd * w[1,2] + P.wd.wd * w[2,2]/2)
    f.ww <- x[4] * (P.ww.ww * w[1,1] + P.wd.ww * w[2,1]/2) + x[5]/2 * (P.ww.wd * w[1,2] + P.wd.wd * w[2,2]/2)
    
    #heterozygotes
    m.wd <- x[4] * (P.wd.ww * w[2,1]/2 + P.dd.ww * w[3,1]) + x[5]/2 * (P.ww.wd * w[1,2] + P.wd.wd * w[2,2] + P.dd.wd * w[3,2]) + x[6] * (P.ww.dd * w[1,3] + P.wd.dd * w[2,3]/2)
    m.wd <- v.m[1] * m.wd
    f.wd <- x[4] * (P.wd.ww * w[2,1]/2 + P.dd.ww * w[3,1]) + x[5]/2 * (P.ww.wd * w[1,2] + P.wd.wd * w[2,2] + P.dd.wd * w[3,2]) + x[6] * (P.ww.dd * w[1,3] + P.wd.dd * w[2,3]/2)
    f.wd <- v.f[1] * f.wd
    
    #drive homozygotes
    m.dd <- x[5]/2 * (P.wd.wd * w[2,2]/2 + P.dd.wd * w[3,2]) + x[6] * (P.wd.dd * w[2,3]/2 + P.dd.dd * w[3,3])
    m.dd <- v.m[2] * m.dd
    f.dd <- x[5]/2 * (P.wd.wd * w[2,2]/2 + P.dd.wd * w[3,2]) + x[6] * (P.wd.dd * w[2,3]/2 + P.dd.dd * w[3,3])
    f.dd <- v.f[2] * f.dd
    
    #normalize GF
    F.f <- c(f.ww, f.wd, f.dd)
    F.f <- F.f/sum(F.f)
    M.f <- c(m.ww, m.wd, m.dd)
    M.f <- M.f/sum(M.f)
    
    #introduce random genetic drift
    if(n.e>0){
      N.m<-t(rmultinom(1,n.e/2,M.f)/(n.e/2))
      N.f<-t(rmultinom(1,n.e/2,F.f)/(n.e/2))
      f<-c(N.m,N.f)
    }
    else {
      f<-c(M.f,F.f)
    }
    #store current generation + overwrite frequencies
    t<-rbind(t,f,deparse.level = 0)
    x<-f
  }
  return(t)
}

