

make.heatmap<-function(df,x.label=NA,y.label=NA,title=NA,my.colors=NA,my.range=NA,bar.min="min",bar.max="max"){
  require(ggplot2)
  require(scales)
  names(df)<-c("p1","p2","stat")
  #calculate ranges
  p1.range<-sort(unique(df$p1))
  p1.range<-diff(p1.range)[1]
  p2.range<-sort(unique(df$p2))
  p2.range<-diff(p2.range)[1]
  #generate basic plot
  g<-ggplot(data = df,aes(x=p1,y=p2))+geom_tile(data=df,aes(fill=stat))+coord_fixed(ratio = p1.range/p2.range)
  g<-g+scale_x_continuous(breaks = seq(0,max(df$p1),length.out = 5))
  g<-g+scale_y_continuous(breaks = seq(0,max(df$p2),length.out = 5))
  g<-g+theme_minimal()+theme(text = element_text(size = 30),legend.text = element_text(size = 30),legend.position = "bottom")
  #additional formating
  if(!is.na(x.label)) g<-g+xlab(x.label)
  if(!is.na(y.label)) g<-g+ylab(y.label)
  if(!is.na(title))   g<-g+ggtitle(title)
  if(!is.na(my.colors[1]) & !is.na(my.range[1])) {
    if(bar.min=="min") bar.min<-min(df$stat,na.rm = T)
    if(bar.max=="max") bar.max<-max(df$stat,na.rm = T)
    g<-g+scale_fill_gradientn(colours = my.colors,values = rescale(my.range),breaks=my.range,labels=round(my.range,4),
                              guide = guide_colorbar(nbin=100, draw.ulim = FALSE, draw.llim = FALSE,direction = "horizontal",label.position = "bottom",barwidth = 20,label.theme = element_text(angle = 90, hjust = 1,size=15)),
                              limits=c(bar.min,bar.max),name="") 
  }
  return(g)
}

